==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EndpointsFluent<A extends EndpointsFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public EndpointsFluent.MetadataNested<A> withNewMetadata();
    public EndpointsFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public EndpointsFluent.MetadataNested<A> editMetadata();
    public EndpointsFluent.MetadataNested<A> editOrNewMetadata();
    public EndpointsFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToSubsets(int index,EndpointSubset item);
    public A setToSubsets(int index,EndpointSubset item);
    public A addToSubsets(EndpointSubset... items);
    public A addAllToSubsets(Collection<EndpointSubset> items);
    public A removeFromSubsets(EndpointSubset... items);
    public A removeAllFromSubsets(Collection<EndpointSubset> items);
    public A removeMatchingFromSubsets(Predicate<EndpointSubsetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubsets instead.
 * @return The buildable object.
 */
@Deprecated public List<EndpointSubset> getSubsets();
    public List<EndpointSubset> buildSubsets();
    public EndpointSubset buildSubset(int index);
    public EndpointSubset buildFirstSubset();
    public EndpointSubset buildLastSubset();
    public EndpointSubset buildMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public Boolean hasMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public A withSubsets(List<EndpointSubset> subsets);
    public A withSubsets(EndpointSubset... subsets);
    public Boolean hasSubsets();
    public EndpointsFluent.SubsetsNested<A> addNewSubset();
    public EndpointsFluent.SubsetsNested<A> addNewSubsetLike(EndpointSubset item);
    public EndpointsFluent.SubsetsNested<A> setNewSubsetLike(int index,EndpointSubset item);
    public EndpointsFluent.SubsetsNested<A> editSubset(int index);
    public EndpointsFluent.SubsetsNested<A> editFirstSubset();
    public EndpointsFluent.SubsetsNested<A> editLastSubset();
    public EndpointsFluent.SubsetsNested<A> editMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<EndpointsFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SubsetsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointSubsetFluent<EndpointsFluent.SubsetsNested<N>> {

            public N and();
            public N endSubset();    }


}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EndpointsFluent<A extends EndpointsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<A> withNewMetadata();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<A> editMetadata();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<A> editOrNewMetadata();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToSubsets(int index,EndpointSubset item);
    public A setToSubsets(int index,EndpointSubset item);
    public A addToSubsets(EndpointSubset... items);
    public A addAllToSubsets(Collection<EndpointSubset> items);
    public A removeFromSubsets(EndpointSubset... items);
    public A removeAllFromSubsets(Collection<EndpointSubset> items);
    public A removeMatchingFromSubsets(Predicate<EndpointSubsetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubsets instead.
 * @return The buildable object.
 */
@Deprecated public List<EndpointSubset> getSubsets();
    public List<EndpointSubset> buildSubsets();
    public EndpointSubset buildSubset(int index);
    public EndpointSubset buildFirstSubset();
    public EndpointSubset buildLastSubset();
    public EndpointSubset buildMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public Boolean hasMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public A withSubsets(List<EndpointSubset> subsets);
    public A withSubsets(EndpointSubset... subsets);
    public Boolean hasSubsets();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> addNewSubset();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> addNewSubsetLike(EndpointSubset item);
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> setNewSubsetLike(int index,EndpointSubset item);
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> editSubset(int index);
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> editFirstSubset();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> editLastSubset();
    public io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<A> editMatchingSubset(Predicate<EndpointSubsetBuilder> predicate);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<io.fabric8.kubernetes.api.model.EndpointsFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SubsetsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointSubsetFluent<io.fabric8.kubernetes.api.model.EndpointsFluent.SubsetsNested<N>> {

            public N and();
            public N endSubset();    }


}
